Epstein-Nesbet second-order perturbation treatment of dynamical electron correlation and ground state potential energy curve of Cr2 - ScienceDirect
Description: The Cr2 potential energy curve is obtained by treating the dynamical correlation energy terms using a CI procedure based on determinants, equivalent t…

Skip to main content Skip to article

- Access through your institution
- Purchase PDF

Search ScienceDirect

## Chemical Physics Letters

Volume 278, Issues 4–6, 31 October 1997, Pages 285-290

# Epstein-Nesbet second-order perturbation treatment of dynamical electron correlation and ground state potential energy curve of Cr2

Author links open overlay panel
,
https://doi.org/10.1016/S0009-2614(97)04014-1
Get rights and content

## Abstract

The Cr2 potential energy curve is obtained by treating the dynamical correlation energy terms using a CI procedure based on determinants, equivalent to multi-reference second-order perturbation theory with the Epstein-Nesbet partition of the Hamiltonian. One of the advantages of this treatment is that the level shifts required for the equivalent Møller-Plesset type of treatment to eliminate intruder states and avoid divergences in the ground state second-order energy expression, are not required. Moreover, by truncating the reference space, the dynamical and the non-dynamical correlation energy is included also for the 3s, 3p electrons. The potentials are compared to experiment and to the most accurate theoretical potential curves in the literature.

## References (35)

- V.E. Bondybey et al.

  ### Chem. Phys. Lett.

  (1983)
- A.D. McLean et al.

  ### Chem. Phys. Lett.

  (1983)
- S.P. Walch et al.

  ### Chem. Phys. Lett.

  (1983)
- G.E. Scuseria et al.

  ### Chem. Phys. Lett.

  (1990)
- C.W. Bauschlicher et al.

  ### Chem. Phys. Lett.

  (1994)
- K. Andersson et al.

  ### Chem. Phys. Lett.

  (1994)
- A.O. Mitrushenkov

  ### Chem. Phys. Lett.

  (1994)
- A.O. Mitrushenkov et al.

  ### Chem. Phys. Lett.

  (1995)
- P.J. Knowles et al.

  ### Chem. Phys. Lett.

  (1985)
- R.J. Gdanitz et al.

  ### Chem. Phys. Lett.

  (1988)

- P.Å. Malmqvist

  ### Chem. Phys. Lett.

  (1995)
- K. Hirao

  ### Chem. Phys. Lett.

  (1992)
- K. Hilpert et al.

  ### Ber. Bunsenges. Phys. Chem.

  (1987)
- S.M. Casey et al.

  ### J. Phys. Chem.

  (1993)
- K.W. Richman et al.

  ### J. Chem. Phys.

  (1987)
- G.E. Scuseria

  ### J. Chem. Phys.

  (1991)
- H.J. Werner et al.

  ### J. Chem. Phys.

  (1988)

## Cited by (21)

- ### On a mixed Møller-Plesset Epstein-Nesbet partition of the Hamiltonian to be used in multireference perturbation configuration interaction

  2000, Chemical Physics Letters
  Citation Excerpt :

  The MP-EN curve (see Fig. 5) is also completely exempt from any intruder problem and shows a qualitatively correct behaviour, with the characteristic `shelf' in correspondence to the 4s–4s bonding region [26], but it is still overbound by ≈0.8 eV. Our MP-EN results are comparable with those of Mitrushenkov and Palmieri [27], who also employ an EN-type perturbation treatment. We have also experimented the imaginary level shift technique of Forsberg and Malmqvist [25]with our MPB partition (MPB+LS) and have obtained the potential curve shown in Fig. 5 at the cost of a large shift of 0.3 a.u.

  Within the frame of second-order multi-reference perturbation theory (MR-PT), drawing on previous work of Dyall, a new partition of the Hamiltonian, which can loosely be considered as intermediate between Møller–Plesset (MP) and Epstein–Nesbet (EN), is presented. The method, which is well suited for CAS-SCF zero-order wavefunctions, is expected to correct partially the defects of MP and EN while retaining their good properties. The new approach has been successfully applied to some test cases involving the homonuclear diatomics F2, Cl2 and N2 where the faults of the EN treatment appear to be in large measure eliminated. Application to the Cr2 diatomic shows that the dramatic intruder state problem suffered by the MP treatment is completely solved, affording a qualitatively good description of the potential energy curve for the ground state.

- ### Cavity ringdown spectroscopy search for transition metal dimers

  1999, Chemical Physics

  A reinvestigation of several isotopic species of Cr2 by the cavity ringdown technique yields a frequency of ΔG1/2=417±4 cm−1 for the A 1 Σ+u state, and casts doubt on the assignment of a band near 21 700 cm−1 previously attributed to the 1–1 transition. Even though copious amounts of Ti2 were produced in our source, search for its transition reported in the same spectral region in matrices yielded no positive results. For both metals investigated, extremely strong absorptions of highly excited metastable atoms were detected.

- ### Efficient truncation strategies for multi-reference configuration interaction molecular energies and properties

  1998, Journal of Chemical Physics

- ### An alternative choice of the zeroth-order Hamiltonian in CASPT2 theory

  2020, Journal of Chemical Physics

- ### Analysis of the structures, stabilities and electronic properties of MB<inf>16</inf><sup>-</sup> (M = V, Cr, Mn, Fe, Co, Ni) clusters and assemblies

  2020, New Journal of Chemistry

- ### The bond length and bond energy of gaseous CrW

  2016, Journal of Chemical Physics

View all citing articles on Scopus
View full text
Copyright © 1997 Published by Elsevier B.V.

- ### Binding affinity and permeation of X12Y12 nanoclusters for helium and neon

  Journal of Molecular Liquids, Volume 244, 2017, pp. 124-134
  Khurshid Ayub

- ### Dissociative adsorption of NO introduces flexibility in gas phase Rh6+ clusters leading to a rich isomeric distribution

  Chemical Physics Letters, Volume 780, 2021, Article 138937
  Fumitaka Mafuné, …, Satoshi Kudoh

- ### Genetic overlap between alcohol use disorder and bulimic behaviors in European American and African American women

  Drug and Alcohol Dependence, Volume 153, 2015, pp. 335-340
  Melissa A. Munn-Chernoff, …, Alexis E. Duncan

- ### A possible reason behind the initial formation of pentagonal dodecahedron cavities in sI-methane hydrate nucleation: A DFT study

  Chemical Physics Letters, Volume 691, 2018, pp. 415-420
  Sukanta Mondal, …, Pratim Kumar Chattaraj

- ### Movement of Ng2 molecules confined in a C60 cage: An ab initio molecular dynamics study

  Chemical Physics Letters, Volumes 610–611, 2014, pp. 351-356
  Munmun Khatua, …, Pratim K. Chattaraj

- ### Short communication: The influence of solids concentration and bleaching agent on bleaching efficacy and flavor of sweet whey powder

  Journal of Dairy Science, Volume 98, Issue 4, 2015, pp. 2294-2302
  M.G. Jervis, …, M.A. Drake

View article metrics